<?php
/**
 * Wembley functions and definitions
 *
 * @package Wembley
 */

/*--------------------------------*
/* Set content width & image sizes
/*-------------------------------*/
if ( ! isset( $content_width ) ) {
	$content_width = 1140; /* pixels */
	add_image_size('lv-portfolio', 400, 400, true);
	add_image_size('lv-menu', 190, 120, true);
	add_image_size('lv-masonry', 400, '', false);
	add_image_size('lv-jumbotron', 9999, 400, true);
	add_image_size('lv-blog', 800, '', false);
}

if ( ! function_exists( 'wembley_setup' ) ) :
/*-------------------------------------------------*
/* Set theme defaults & register WP feature support
/*------------------------------------------------*/
function wembley_setup() {
	/*
	 * Make theme available for translation.
	 */
	load_theme_textdomain( 'wembley', get_template_directory() . '/languages' );
	/*
	 *RSS feed
	 */
	add_theme_support( 'automatic-feed-links' );
	/*
	 * Let WordPress manage the document title.
	 */
	add_theme_support( 'title-tag' );
	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 */
	add_theme_support( 'post-thumbnails' );
	/*
	 * Register menu.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'wembley' ),
	) );
     /*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );
	/*
	 * Jetpack support.
	 */
	add_theme_support( 'jetpack-portfolio' );
     /*
	 * Enable support for Post Formats.
	 */
	add_theme_support( 'post-formats', array(
		'audio', 'video', 'quote', 'gallery'
	) );
	/*
	 * Custom background.
	 */
	add_theme_support( 'custom-background', apply_filters( 'wembley_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // wembley_setup
add_action( 'after_setup_theme', 'wembley_setup' );

/*--------------------------*
/* Register widget area
/*--------------------------*/

function wembley_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'wembley' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<div class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3><span class="wb-line"></span>',
	) );
	
    include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
    if (is_plugin_active('advanced-custom-fields-pro/acf.php')){ //Check to see if ACF is installed
    if (get_field('sidebars','option')){
    while (has_sub_field('sidebars','option')){ //Loop through sidebar fields to generate custom sidebars
    $s_name = get_sub_field('sidebar_name','option');
    $s_id = str_replace(" ", "-", $s_name); // Replaces spaces in Sidebar Name to dash
    $s_id = strtolower($s_id); // Transforms edited Sidebar Name to lowercase
    register_sidebar( array(
    'name' => $s_name,
    'id' => $s_id,
	'description'   => '',
	'before_widget' => '<div class="widget %2$s">',
	'after_widget'  => '</div>',
	'before_title'  => '<h3 class="widget-title">',
	'after_title'   => '</h3><span class="wb-line"></span>',
    ) );
    };
    };
    };
   };
add_action( 'widgets_init', 'wembley_widgets_init' );
/*--------------------------*
/* Dynamic sidebars
/*--------------------------*/
function wembley_load_sidebar( $field )
{
 // reset choices
 $field['choices'] = array();
 $field['choices']['default'] = 'Default Sidebar';
 // load repeater from the options page
 if(get_field('sidebars', 'option'))
 {
 // loop through the repeater and use the sub fields "value" and "label"
 while(has_sub_field('sidebars', 'option'))
 {
 
 $label = get_sub_field('sidebar_name');
 $value = str_replace(" ", "-", $label);
 $value = strtolower($value);
 
$field['choices'][ $value ] = $label;
 
}
 }
 
 // Important: return the field
 return $field;
}
 
add_filter('acf/load_field/name=select_a_sidebar', 'wembley_load_sidebar');


/*require_once( get_template_directory() . '/inc/sidebars/sbars.php');*/

/**
 * Enqueue scripts and styles.
 */
function wembley_scripts() {
	wp_enqueue_style('pe_icon_css', get_template_directory_uri() . "/css/pe-icon-7-stroke.css", 'screen');
	wp_enqueue_style( 'wembley-style', get_stylesheet_uri() );
    wp_enqueue_style( 'wembley-font-awesome', get_template_directory_uri() . "/css/font-awesome.min.css", array(), '4.2.0' );
	wp_enqueue_style('googleFont', 'http://fonts.googleapis.com/css?family=Raleway:400,500,300,600,700|Montserrat:400,700');
	wp_enqueue_script( 'wembley-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20141215', true );
	wp_enqueue_script( 'wembley-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
	wp_enqueue_script( 'wembley-classie', get_template_directory_uri() . '/js/classie.js', array(), '20141215', true );
	wp_enqueue_script('wembley-svg', get_template_directory_uri() . '/js/snap.svg-min.js', array('jquery'), '', true);
	wp_enqueue_script('wembley-mojo', get_template_directory_uri() . '/js/theia-sticky-sidebar.js', array('jquery'), '', true);
	wp_enqueue_script('masonry',array(), '', true);
	if((is_archive() ||  is_home())  && (( get_theme_mod('blog_layout') == 'masonry_side' || get_theme_mod('blog_layout') == 'masonry')) && (!is_category('demo'))) {
	wp_enqueue_script('masonry-script',get_template_directory_uri() . '/js/masonry-script.js',	array('jquery'), '', true);
    }
	wp_enqueue_script('wembley_countTo', get_template_directory_uri() . '/js/jquery.countTo.js', false, false, true);
	wp_enqueue_script('wembley_circliful', get_template_directory_uri() . '/js/jquery.circliful.min.js', false, false, true);
	wp_enqueue_script( 'wembley-magnific', get_template_directory_uri() . '/js/jquery.magnific-popup.min.js',  array(), '20141215', true );
	wp_enqueue_script( 'wembley-main', get_template_directory_uri() . '/js/jquery.main.js',  array('jquery'), '20141215', true );
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'wembley_scripts' );
/*--------------------------*
/* Custom headers
/*--------------------------*/
require get_template_directory() . '/inc/custom-header.php';
/*--------------------------*
/* Template tags
/*--------------------------*/
require get_template_directory() . '/inc/template-tags.php';
/*--------------------------*
/* Extras
/*--------------------------*/
require get_template_directory() . '/inc/extras.php';
/*--------------------------*
/* Customizer
/*--------------------------*/
require get_template_directory() . '/inc/customizer.php';
/*--------------------------*
/* Load Jetpack file
/*--------------------------*/
require get_template_directory() . '/inc/jetpack.php';
/*--------------------------*
/* Demo Content
/*--------------------------*/
require get_template_directory() . '/inc/import/init.php';
/*--------------------------*
/* Add Custom Fields
/*--------------------------*/
add_filter('acf/settings/show_admin', '__return_false');
$value= '';
require_once('inc/custom-fields.php');
if( function_exists('acf_add_options_page') ) {
	acf_add_options_page(array(
			'page_title' 	=> 'Custom Sidebars',
			'menu_title'	=> 'Sidebars',
			'menu_slug' 	=> 'theme-sidebar-settings',
			'capability'	=> 'edit_posts',
			'redirect'		=> false
		));
	
	
}
/*--------------------------*
/* Plugins
/*--------------------------*/
require_once( 'inc/plugins/plugin.php');
/*--------------------------*
/* Excerpt Length
/*--------------------------*/
function wembley_excerpt_length( $length ) {
	return 20;
}
add_filter( 'excerpt_length', 'wembley_excerpt_length', 999 );

function wembley_excerpt_more( $more ) {
	return ' <a class="read-more" href="'. get_permalink( get_the_ID() ) . '">' . __('>>', 'your-text-domain') . '</a>';
}
add_filter( 'excerpt_more', 'wembley_excerpt_more' );
/*--------------------------*
/* Hex to RGB
/*--------------------------*/
function hex2rgb($hex) {
    $hex = str_replace("#", "", $hex);
    if (preg_match("/^([a-f0-9]{3}|[a-f0-9]{6})$/i",$hex)):      // check if input string is a valid hex colour code
        if(strlen($hex) == 3) { // three letters code
           $r = hexdec(substr($hex,0,1).substr($hex,0,1));
           $g = hexdec(substr($hex,1,1).substr($hex,1,1));
           $b = hexdec(substr($hex,2,1).substr($hex,2,1));
        } else { // six letters coode
           $r = hexdec(substr($hex,0,2));
           $g = hexdec(substr($hex,2,2));
           $b = hexdec(substr($hex,4,2));
        }
        return implode(",", array($r, $g, $b)); 
    else: return "";  
    endif;
} // hex2rgb()
/*--------------------------*
/* Customizations
/*--------------------------*/
function wembley_customize_css()
{
	$wb_color = esc_attr(get_theme_mod('highlight_color'));
	$wb_img = esc_attr(get_theme_mod('menu_image'));
    ?>
 <style type="text/css">
             a,.logo a,.twocolumns h2 a:hover,.twocolumns h3 a:hover,.post-info .date:hover,.commentlist .author:hover,#sidebar .widget a:hover,#sidebar .widget a:focus,#sidebar .widget ul li a:hover span,.post .post-info a:hover,.post .post-info a:hover time,.post .aside .date:hover,.post .aside .date:hover time,.tags a:hover,.aside h2 a:hover,.aside .author a:hover,.controls a:hover, .effect-winston a:hover,.effect-winston a:focus,#sidebar .widget .really_simple_twitter_widget li a, .services-section .icon,.icon-like:before,.effect-content ul li:first-child a{ color:<?php echo $wb_color; ?>; }
			 
			#sidebar .widget h3:after,.aside h2:after,.pagination ul a:hover,.btn:hover,#infinite-handle span:hover,.morphsearch:after,.masonry .blog .cat-list,.wb-caption, .tab-column .tabset a,#filters li a,.accordion .opener_ac,.social-networks a:hover, .services-section .service-column.active,.services-section .service-column:hover,.green-block,.about-section,.about-section .btn,.about-section .btn:hover,input[type="submit"]:hover,
.btn:hover, #infinite-handle span:hover,input[type="submit"]:hover,
.btn:hover, .button:hover, #infinite #infinite-handle span:hover, .pagination ul li.active a, #sidebar .wb-line { background:<?php echo esc_attr($wb_color); ?>; }
			
			.pagination ul li.active a,.pagination ul a:hover,.social-networks a:hover,.services-section .service-column.active .icon,.services-section .service-column:hover .icon{ border-color:<?php echo esc_attr(get_theme_mod('highlight_color')); ?>; }
			.wb-caption{background:linear-gradient(to bottom, rgba(<?php echo hex2rgb($wb_color); ?>, 0.55) 0%, rgba(<?php echo hex2rgb($wb_color); ?>, 0.55) 100%) repeat scroll 0 0 rgba(0, 0, 0, 0)}
			.main-nav .button--line.active .morph-shape svg{fill:<?php echo esc_attr($wb_color); ?>; }
			
			.morphsearch {background:linear-gradient(to bottom, rgba(<?php echo hex2rgb($wb_color); ?>, 0.95) 0%, rgba(<?php echo hex2rgb($wb_color); ?>, 0.95) 100%) repeat scroll 0 0 rgba(0, 0, 0, 0)}
			<?php if(!empty($wb_img)) { ?>
			.wb-pg {background-image: url("<?php echo esc_url($wb_img); ?>");}
			.morphsearch {background:#000;}
			<?php } ?>
         </style>
    <?php
}
add_action( 'wp_head', 'wembley_customize_css');
/*--------------------------*
/* Sanitize Custom Fields
/*--------------------------*/
function wembley_get_field( $key, $id=false, $default='' ) {
  global $post;
  $key = trim( filter_var( $key, FILTER_SANITIZE_STRING ) );
  $result = '';
 
  if ( function_exists( 'get_field' ) ) {
    $result = ( isset( $post->ID ) && ! $id ? get_field( $key ) : get_field( $key, $id ) );
 
    if ( $result == '' ) {
      $result = $default;
    }
  } else { 
    $result = $default;
  }
  return $result;
}

function wembley_sub_field_escaped($field_key, $post_id = false, $format_value = true, $escape_method = 'esc_html')
{
    $field = get_sub_field($field_key, $post_id, $format_value);
 
    if($field === NULL || $field === FALSE)
        $field = '';
 
    if(is_array($field))
    {
        $field_escaped = array();
        foreach($field as $key => $value)
        {
            $field_escaped[$key] = ($escape_method === NULL) ? $value : $escape_method($value);
        }
        return $field_escaped;
    }
    else
        return ($escape_method === NULL) ? $field : $escape_method($field);
}