<?php
/**
 * Wembley Theme Customizer
 *
 * @package Wembley
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function wembley_sanitize_choices( $input, $setting ) {
    global $wp_customize;
 
    $control = $wp_customize->get_control( $setting->id );
 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}
function wembley_sanitize_text( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}
function wembley_sanitize_checkbox( $input ) {
    if ( $input == 1 ) {
        return 1;
    } else {
        return '';
    }
}
function wembley_customize_register( $wp_customize ) {
    //Wembley Options
 $wp_customize->add_section( 'wembley_theme_customizer_basic', array(
	'title' => __( 'Logo', 'wembley' ),
	'priority' => 100
) );

//Logo Image
$wp_customize->add_setting( 'logo_image', array( 
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'logo_image', array(
	'label' => __( 'Logo Upload', 'wembley' ),
	'section' => 'wembley_theme_customizer_basic',
	'settings' => 'logo_image'
	
) ) );
	
	
	//Highlight Color
  $wp_customize->add_setting( 'highlight_color', array(
	'default' => '#dd1c60',
	'sanitize_callback' => 'sanitize_hex_color',
	 'transport' => 'postMessage'
	) );
	

	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'highlight_color', array(
		'label'   => __( 'Highlight Color', 'wembley' ),
		'section' => 'colors',
		'settings'   => 'highlight_color'
		
	) ) );
		
		
	    $wp_customize->add_section( 'wembley_theme_customizer_layout', array(
	   	'title' => __( 'Blog Layout', 'wembley' ),
	   	'priority' => 200
	   ) );
		
		//Blog Style
	  $wp_customize->add_setting( 'blog_layout', array(
		  'default' => 'full',
		  'sanitize_callback' => 'wembley_sanitize_choices',
		) );
	

	
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'blog_layout', array(
			'label'   => __( 'Default Category Style', 'wembley' ),
			'section' => 'wembley_theme_customizer_layout',
			'settings'   => 'blog_layout',
		     'type'       => 'radio',
		        'choices'    => array(
		            'full' => 'Standard',
		            'sidebar' => 'Sidebar',
		            'masonry' => 'Masonry',
					'masonry_side' => 'Masonry/sidebar'
		        ),
		    )));
			
			$wp_customize->add_setting('post_content', array(
		  'sanitize_callback' => 'wembley_sanitize_checkbox',
		  'default' => '1',
		) );
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'post_content', array(
		        'type' => 'checkbox',
		        'label' => 'Hide default editor (recommended)',
		        'section' => 'wembley_theme_customizer_layout',
		)));
			
			
		    $wp_customize->add_section( 'wembley_theme_customizer_footer', array(
		   	'title' => __( 'Footer', 'wembley' ),
		   	'priority' => 300
		   ) );
		
			//Footer
		  $wp_customize->add_setting( 'footer_layout', array(
			  'default' => 'All Rights Reserved.',
			  'sanitize_callback' => 'wembley_sanitize_text',
			) );
	

	
			$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'footer_layout', array(
				'label'   => __( 'Copyright', 'wembley' ),
				'section' => 'wembley_theme_customizer_footer',
				'settings'   => 'footer_layout',
				
			    )));
			
		
			//Menu Style
		  $wp_customize->add_setting( 'menu_layout', array(
			  'default' => 'simple',
			  'sanitize_callback' => 'wembley_sanitize_choices',
			) );
	

	
			$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'menu_layout', array(
				'label'   => __( 'Primary Menu Style', 'wembley' ),
				'section' => 'menu_locations',
				'settings'   => 'menu_layout',
			     'type'       => 'radio',
			        'choices'    => array(
			            'simple' => 'Simple Menu',
			            'visual' => 'Visual Menu',
			        ),
			    )));
				//Menu Image
				$wp_customize->add_setting( 'menu_image', array( 
					'sanitize_callback' => 'esc_url_raw',
				) );

				$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'menu_image', array(
					'label' => __( 'Primary Menu Image Upload', 'wembley' ),
					'description' =>'Optional Menu Background Image',
					'section' => 'menu_locations',
					'settings' => 'menu_image'
	
				) ) );
		
	//Social Settings
	$wp_customize->add_section( 'wembley_theme_customizer_social', array(
		'title' => __( 'Social Settings', 'wembley' ),
		'priority' => 700
	) );
	
	$wp_customize->add_setting( 'twitter_text', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		 'priority' => 1
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'twitter_text', array(
		'label'   => __( 'Twitter username', 'wembley' ),
		'section' => 'wembley_theme_customizer_social',
		'settings'   => 'twitter_text',
		
	) ) );
	
	
	$wp_customize->add_setting( 'facebook_text', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		 'priority' => 2
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'facebook_text', array(
		'label'   => __( 'Facebook username', 'wembley' ),
		'section' => 'wembley_theme_customizer_social',
		'settings'   => 'facebook_text',
		
	) ) );
	
	$wp_customize->add_setting( 'pinterest_text', array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		 'priority' => 3
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'pinterest_text', array(
		'label'   => __( 'Pinterest url', 'wembley' ),
		'section' => 'wembley_theme_customizer_social',
		'settings'   => 'pinterest_text',
		
	) ) );
	
	$wp_customize->add_setting( 'google1_text', array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		 'priority' => 4
	) );
	
	
	$wp_customize->add_setting( 'dribbble_text', array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		 'priority' => 5
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'dribbble_text', array(
		'label'   => __( 'Dribbble url', 'wembley' ),
		'section' => 'wembley_theme_customizer_social',
		'settings'   => 'dribbble_text',
		
	) ) );
	
	$wp_customize->add_setting( 'flickr_text', array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		 'priority' => 6
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'flickr_text', array(
		'label'   => __( 'Flickr url', 'wembley' ),
		'section' => 'wembley_theme_customizer_social',
		'settings'   => 'flickr_text',
		
	) ) );
	
	$wp_customize->add_setting( 'youtube_text', array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		 'priority' => 7
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'youtube_text', array(
		'label'   => __( 'YouTube url', 'wembley' ),
		'section' => 'wembley_theme_customizer_social',
		'settings'   => 'youtube_text',
		
	) ) );
	
	$wp_customize->add_setting( 'instagram_text', array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		 'priority' => 8
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'instagram_text', array(
		'label'   => __( 'Instagram url', 'wembley' ),
		'section' => 'wembley_theme_customizer_social',
		'settings'   => 'instagram_text',
		
	) ) );
	
	$wp_customize->add_setting( 'vimeo_text', array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		 'priority' => 9
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'vimeo_text', array(
		'label'   => __( 'Vimeo url', 'wembley' ),
		'section' => 'wembley_theme_customizer_social',
		'settings'   => 'vimeo_text',
		
	) ) );
	
	$wp_customize->add_setting( 'behance_text', array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		 'priority' => 10
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'behance_text', array(
		'label'   => __( 'Behance url', 'wembley' ),
		'section' => 'wembley_theme_customizer_social',
		'settings'   => 'behance_text',
		
	) ) );
	
	$wp_customize->add_setting( 'linkedin_text', array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		 'priority' => 1
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'linkedin_text', array(
		'label'   => __( 'LinkedIn url', 'wembley' ),
		'section' => 'wembley_theme_customizer_social',
		'settings'   => 'linkedin_text',
		
	) ) );
	
	//Real Time Settings Preview
	
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	
	
	$wp_customize->remove_control( 'background_color');
	$wp_customize->remove_section( 'background_image');
	
	
}
add_action( 'customize_register', 'wembley_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function wembley_customize_preview_js() {
	wp_enqueue_script( 'wembley_customizer', get_template_directory_uri() . '/inc/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'wembley_customize_preview_js' );
