<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Wembley
 */
/*--------------------------*
/* Pagination
/*--------------------------*/
if ( ! function_exists( 'wembley_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 */
	function wembley_paging_nav() {

		if( is_singular() )
			return;

		global $wp_query;

		/** Stop execution if there's only 1 page */
		if( $wp_query->max_num_pages <= 1 )
			return;

		$paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
		$max   = intval( $wp_query->max_num_pages );

		/**	Add current page to the array */
		if ( $paged >= 1 )
			$links[] = $paged;

		/**	Add the pages around the current page to the array */
		if ( $paged >= 3 ) {
			$links[] = $paged - 1;
			$links[] = $paged - 2;
		}

		if ( ( $paged + 2 ) <= $max ) {
			$links[] = $paged + 2;
			$links[] = $paged + 1;
		}

		echo '<div class="pagination"><ul class="paging">' . "\n";

		/**	Previous Post Link */
		if ( get_previous_posts_link() )
			printf( '<li>%s</li>' . "\n", get_previous_posts_link('<') );

		/**	Link to first page, plus ellipses if necessary */
		if ( ! in_array( 1, $links ) ) {
			$class = 1 == $paged ? ' class="active"' : '';

			printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( 1 ) ), '1' );

			if ( ! in_array( 2, $links ) )
				echo '<li>...</li>';
		}

		/**	Link to current page, plus 2 pages in either direction if necessary */
		sort( $links );
		foreach ( (array) $links as $link ) {
			$class = $paged == $link ? ' class="active"' : '';
			printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $link ) ), $link );
		}

		/**	Link to last page, plus ellipses if necessary */
		if ( ! in_array( $max, $links ) ) {
			if ( ! in_array( $max - 1, $links ) )
				echo '<li>...</li>' . "\n";

			$class = $paged == $max ? ' class="active"' : '';
			printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $max ) ), $max );
		}

		/**	Next Post Link */
		if ( get_next_posts_link() )
			printf( '<li>%s</li>' . "\n", get_next_posts_link('>') );

		echo '</ul></div>' . "\n";

	}
endif;
/*--------------------------*
/* Post navigation
/*--------------------------*/
if ( ! function_exists( 'wembley_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 */
function wembley_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<ul class="button-controls">
		<?php if ( $previous ) { ?>
	<li class="btn-prev button button--line button--wb active"><span class="morph-shape" data-morph-active="M286,113c0,0-68.8,9-136,9c-78.2,0-137-9-137-9S3,97.198,3,62.5C3,33.999,13,12,13,12S72,2,150,2c85,0,136,10,136,10s11,17.598,11,52C297,96.398,286,113,286,113z">
									<svg width="100%" height="100%" viewBox="0 0 300 125" preserveAspectRatio="none">
										<path d="M286.5,113c0,0-104,0-136.5,0c-35.75,0-136.5,0-136.5,0s0-39.417,0-52.5c0-12.167,0-48.5,0-48.5s101.833,0,136.5,0c33.583,0,136.5,0,136.5,0s0,35.917,0,48.5C286.5,73.167,286.5,113,286.5,113z"/>
									</svg>
								</span><span class="button__text"><?php
				previous_post_link('%link', __('< previous', 'wembley'), ''); ?></span</li>
				<?php } if ( $next ) { ?>
				<li class="btn-next button button--line button--wb active"><span class="morph-shape" data-morph-active="M286,113c0,0-68.8,9-136,9c-78.2,0-137-9-137-9S3,97.198,3,62.5C3,33.999,13,12,13,12S72,2,150,2c85,0,136,10,136,10s11,17.598,11,52C297,96.398,286,113,286,113z">
												<svg width="100%" height="100%" viewBox="0 0 300 125" preserveAspectRatio="none">
													<path d="M286.5,113c0,0-104,0-136.5,0c-35.75,0-136.5,0-136.5,0s0-39.417,0-52.5c0-12.167,0-48.5,0-48.5s101.833,0,136.5,0c33.583,0,136.5,0,136.5,0s0,35.917,0,48.5C286.5,73.167,286.5,113,286.5,113z"/>
												</svg>
											</span><span class="button__text"><?php
							next_post_link('%link', __('next >', 'wembley'), ''); ?></span</li>
							<?php } ?>
	
	</ul>
	
	
	<?php
}
endif;
/*--------------------------*
/* Posted on
/*--------------------------*/
if ( ! function_exists( 'wembley_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function wembley_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = sprintf(
		_x( 'Posted on %s', 'post date', 'wembley' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);
	
	$posted_on_blog = sprintf(
		_x( '%s', 'post date', 'wembley' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);
	
	$cats = sprintf(
		_x( 'Posted in %s', 'post categories', 'wembley' ),
		'<span class="cat-list">' . get_the_category_list( __( ', ', 'wembley' ) )  .'</span>'
	);
	
	$cats_blog = sprintf(
		_x( '| %s', 'post categories', 'wembley' ),
		'<span class="cat-list">' . get_the_category_list( __( ', ', 'wembley' ) )  .'</span>'
	);
	
	 $blog_style = get_theme_mod('blog_layout'); 
	 
	 if ( is_singular('post') ) {
	 	echo '<span> ' . $cats . '</span><span class="author"> '._x('by:', 'wembley').' <a href="'. esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ).'">'. esc_html( get_the_author() ) .'</a></span>';
	 }
	elseif ( get_theme_mod( 'blog_layout' ) == 'masonry' || get_theme_mod( 'blog_layout' ) == 'masonry_side') {
		echo '<span class="posted-on">' . $posted_on_blog . '</span>';
		
	$num_comments = get_comments_number();
	if ( $num_comments > 0 ) { 
		echo '<span> | <a href="' . esc_url( get_comments_link() ) . '" rel="bookmark">' . get_comments_number( '', 'one', '%' ) .' <i class="fa fa-comment-o"></i></a></span>'; 
	} 
	} 
else {

	echo '<span> ' . $cats . ' | <a href="' . esc_url( get_comments_link() ) . '" rel="bookmark">' . get_comments_number( 'no responses', 'one response', '% responses' ) .' '._x('comments', 'wembley').'</a></span>';
}
}
endif;
/*--------------------------*
/* Post footer
/*--------------------------*/
if ( ! function_exists( 'wembley_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function wembley_entry_footer() {
	// Hide tag text for pages.
	if ( 'post' == get_post_type() ) {

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', __( ', ', 'wembley' ) );
		if ( $tags_list ) {
			printf( '<span class="tags-links">' . __( 'Tags %1$s ', 'wembley' ) . '</span>', $tags_list );
		}
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		comments_popup_link( __( 'Leave a comment ', 'wembley' ), __( '1 Comment', 'wembley' ), __( '% Comments', 'wembley' ) );
		echo '</span>';
	}

	edit_post_link( __( 'Edit', 'wembley' ), '<span class="edit-link">', '</span>' );
	
	if ( get_the_author_meta('description') ) : ?>
	
	<div class="author-bio">
	<h4>About <?php the_author_link(); ?> </h4>
	<div class="holder">
		<?php echo get_avatar( get_the_author_meta( 'user_email' ), 70 ); ?>
		<div class="text">
			<?php the_author_meta('description')  ?> 
		</div>
	</div>
</div>
<?php endif; 
}

endif;
/*--------------------------*
/* Archive title
/*--------------------------*/
if ( ! function_exists( 'the_archive_title' ) ) :
/**
 * Shim for `the_archive_title()`.
 *
 * Display the archive title based on the queried object.
 *
 * @todo Remove this function when WordPress 4.3 is released.
 *
 * @param string $before Optional. Content to prepend to the title. Default empty.
 * @param string $after  Optional. Content to append to the title. Default empty.
 */
function the_archive_title( $before = '', $after = '' ) {
	if ( is_category() ) {
		$title = sprintf( __( '%s', 'wembley' ), single_cat_title( '', false ) );
	} elseif ( is_tag() ) {
		$title = sprintf( __( 'Tag: %s', 'wembley' ), single_tag_title( '', false ) );
	} elseif ( is_author() ) {
		$title = sprintf( __( 'Author: %s', 'wembley' ), '<span class="vcard">' . get_the_author() . '</span>' );
	} elseif ( is_year() ) {
		$title = sprintf( __( 'Year: %s', 'wembley' ), get_the_date( _x( 'Y', 'yearly archives date format', 'wembley' ) ) );
	} elseif ( is_month() ) {
		$title = sprintf( __( 'Month: %s', 'wembley' ), get_the_date( _x( 'F Y', 'monthly archives date format', 'wembley' ) ) );
	} elseif ( is_day() ) {
		$title = sprintf( __( 'Day: %s', 'wembley' ), get_the_date( _x( 'F j, Y', 'daily archives date format', 'wembley' ) ) );
	} elseif ( is_tax( 'post_format', 'post-format-aside' ) ) {
		$title = _x( 'Asides', 'post format archive title', 'wembley' );
	} elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
		$title = _x( 'Galleries', 'post format archive title', 'wembley' );
	} elseif ( is_tax( 'post_format', 'post-format-image' ) ) {
		$title = _x( 'Images', 'post format archive title', 'wembley' );
	} elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
		$title = _x( 'Videos', 'post format archive title', 'wembley' );
	} elseif ( is_tax( 'post_format', 'post-format-quote' ) ) {
		$title = _x( 'Quotes', 'post format archive title', 'wembley' );
	} elseif ( is_tax( 'post_format', 'post-format-link' ) ) {
		$title = _x( 'Links', 'post format archive title', 'wembley' );
	} elseif ( is_tax( 'post_format', 'post-format-status' ) ) {
		$title = _x( 'Statuses', 'post format archive title', 'wembley' );
	} elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
		$title = _x( 'Audio', 'post format archive title', 'wembley' );
	} elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
		$title = _x( 'Chats', 'post format archive title', 'wembley' );
	} elseif ( is_post_type_archive() ) {
		$title = sprintf( __( 'Archives: %s', 'wembley' ), post_type_archive_title( '', false ) );
	} elseif ( is_tax() ) {
		$tax = get_taxonomy( get_queried_object()->taxonomy );
		/* translators: 1: Taxonomy singular name, 2: Current taxonomy term */
		$title = sprintf( __( '%1$s: %2$s', 'wembley' ), $tax->labels->singular_name, single_term_title( '', false ) );
	} else {
		$title = __( 'Archives', 'wembley' );
	}

	/**
	 * Filter the archive title.
	 *
	 * @param string $title Archive title to be displayed.
	 */
	$title = apply_filters( 'get_the_archive_title', $title );

	if ( ! empty( $title ) ) {
		echo $before . $title . $after;
	}
}

endif;

if ( ! function_exists( 'the_archive_description' ) ) :
/**
 * Shim for `the_archive_description()`.
 *
 * Display category, tag, or term description.
 *
 * @todo Remove this function when WordPress 4.3 is released.
 *
 * @param string $before Optional. Content to prepend to the description. Default empty.
 * @param string $after  Optional. Content to append to the description. Default empty.
 */
function the_archive_description( $before = '', $after = '' ) {
	$description = apply_filters( 'get_the_archive_description', term_description() );

	if ( ! empty( $description ) ) {
		/**
		 * Filter the archive description.
		 *
		 * @see term_description()
		 *
		 * @param string $description Archive description to be displayed.
		 */
		echo $before . $description . $after;
	}
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function wembley_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'wembley_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'wembley_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so wembley_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so wembley_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in wembley_categorized_blog.
 */
function wembley_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'wembley_categories' );
}
add_action( 'edit_category', 'wembley_category_transient_flusher' );
add_action( 'save_post',     'wembley_category_transient_flusher' );

function wb_paginate() {
global $wp_query, $wp_rewrite;
$wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;

$pagination = array(
    'base' => @add_query_arg('page','%#%'),
    'format' => '',
    'total' => $wp_query->max_num_pages,
    'current' => $current,
    'show_all' => true,
    'type' => 'list',
    'next_text' => '&raquo;',
    'prev_text' => '&laquo;'
    );

if( $wp_rewrite->using_permalinks() )
    $pagination['base'] = user_trailingslashit( trailingslashit( remove_query_arg( 'page', get_pagenum_link( 1 ) ) ) . '?page=%#%/', 'paged' );

if( !empty($wp_query->query_vars['s']) )
    $pagination['add_args'] = array( 's' => get_query_var( 's' ) );

echo paginate_links( $pagination );
}
/*--------------------------*
/* Custom Comments Walker
/*--------------------------*/

class wb_comment_walker extends Walker_Comment {
		var $tree_type = 'comment';
		var $db_fields = array( 'parent' => 'comment_parent', 'id' => 'comment_ID' );
 
		//constructor wrapper for the comments list
		function __construct() { ?>
 
			<section class="commentlist">
 
		<?php }
 
		// start_lvl wrapper for child comments list
		function start_lvl( &$output, $depth = 0, $args = array() ) {
			$GLOBALS['comment_depth'] = $depth + 2; ?>
			
			<section class="child-comments commentslist">
 
		<?php }
	
		// end_lvl closing wrapper for child comments list
		function end_lvl( &$output, $depth = 0, $args = array() ) {
			$GLOBALS['comment_depth'] = $depth + 2; ?>
 
			</section>
 
		<?php }
 
		// start_el HTML for comment template
		function start_el( &$output, $comment, $depth = 0, $args = array(), $id = 0 ) {
			$depth++;
			$GLOBALS['comment_depth'] = $depth;
			$GLOBALS['comment'] = $comment;
			$parent_class = ( empty( $args['has_children'] ) ? '' : 'parent' ); 
	
			if ( 'article' == $args['style'] ) {
				$tag = 'article';
				$add_below = 'comment';
			} else {
				$tag = 'article';
				$add_below = 'comment';
			} ?>
 
			<article <?php comment_class(empty( $args['has_children'] ) ? '' :'parent') ?> id="comment-<?php comment_ID() ?>" itemscope itemtype="http://schema.org/Comment">
				 <div class="commentlist-item">
				<div class="comment">
					<div class="avatar-holder">
						<?php echo get_avatar( $comment, 65, '', 'Authors gravatar' ); ?>
					</div>
					<div class="commentlist-holder">
						<a href="<?php comment_author_url(); ?>" class="author"><?php comment_author(); ?></a>
						<p class="meta"><span class="date"><time datetime="2014-11-24"><?php comment_date('jS F Y') ?> at <?php comment_time('H:i') ?></time></span> | <?php comment_reply_link(array_merge( $args, array('add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth']))) ?></p>
						<?php comment_text() ?>
					</div>
				</div>
				</div>
	<?php }
 
		// end_el closing HTML for comment template
		function end_el(&$output, $comment, $depth = 0, $args = array() ) { ?>
 
			</article>

		<?php }
 
		// destructor closing wrapper for the comments list
		function __destruct() { ?>
 
			</section>
		
		<?php }
	}
	
	
	/*--------------------------*
	/* Visual Menu Walker
	/*--------------------------*/
	class wembley_walker_nav_menu extends Walker_Nav_Menu {
  
	// add classes to ul sub-menus
	function start_lvl( &$output, $depth = 0, $args = array() ) {
	    // depth dependent classes
	    $indent = ( $depth > 0  ? str_repeat( "\t", $depth ) : '' ); // code indent
	    $display_depth = ( $depth + 1); // because it counts the first submenu as 0
	    $classes = array(
	        'sub-menu visual-nav',
	        ( $display_depth % 2  ? 'menu-odd' : 'menu-even' ),
	        ( $display_depth >=2 ? 'sub-sub-menu' : '' ),
	        'menu-depth-' . $display_depth
	        );
	    $class_names = implode( ' ', $classes );
  
	    // build html
	    $output .= "\n" . $indent . '<ul class="' . $class_names . '">' . "\n";
	}
  
	// add main/sub classes to li's and links
	 function start_el(  &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
	    global $wp_query;
	    $indent = ( $depth > 0 ? str_repeat( "\t", $depth ) : '' ); // code indent
  
	    // depth dependent classes
	    $depth_classes = array(
	        ( $depth == 0 ? 'main-menu-item' : 'sub-menu-item' ),
	        ( $depth >=2 ? 'sub-sub-menu-item' : '' ),
	        ( $depth % 2 ? 'menu-item-odd' : 'menu-item-even' ),
	        'menu-item-depth-' . $depth
	    );
	    $depth_class_names = esc_attr( implode( ' ', $depth_classes ) );
  
	    // passed classes
	    $classes = empty( $item->classes ) ? array() : (array) $item->classes;
	    $class_names = esc_attr( implode( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) ) );
		
		$image_link='';
		if ( 'taxonomy' == $item->type ) {
		$taxonomy = 'category';
		$term_id = $item->object_id;
		$image = get_field('menu_image',$taxonomy . '_' . $term_id);
		$size = 'lv-menu';
		
	    // build html
	    $image_link .= $indent . '<li id="nav-menu-item-'. $item->ID . '" class="' . $depth_class_names . ' ' . $class_names . '">'.wp_get_attachment_image( $image, $size );
	} else {
		$imaged = get_field('menu_image', $item->object_id);
		$sized = 'lv-menu';
	    $image_link .= $indent . '<li id="nav-menu-item-'. $item->ID . '" class="' . $depth_class_names . ' ' . $class_names . '">'.wp_get_attachment_image( $imaged, $sized );
	}
	
	    // link attributes
	    $attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
	    $attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
	    $attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
	    $attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';
	    $attributes .= ' class="menu-link ' . ( $depth > 0 ? 'sub-menu-link' : 'main-menu-link' ) . '"';
  
	    $item_output = sprintf( '%1$s<a%2$s>%3$s%4$s%5$s</a>%6$s',
	        $args->before,
	        $attributes,
	        $args->link_before,
			$image_link,
	        apply_filters( 'the_title', $item->title, $item->ID ),
	        $args->link_after,
	        $args->after
	    );
	// build html
	    $output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
	}
	}
	/*--------------------------*
	/* Main Nav
	/*--------------------------*/
	function wembley_main_nav() { ?>
	
	<div id="morphsearch" class="morphsearch">
		<div class="morphsearch-form">
			<span class="morphsearch-input"><span></span></span>
		</div>
			<div class="morphsearch-content">
				
				<?php $menu_setting  = get_theme_mod('menu_layout'); 
               if($menu_setting == 'visual'){  ?>
               <nav id="nav" class="alt-nav">
		      <?php wp_nav_menu( array( 'theme_location' => 'primary', 'container' => 'nav', 'menu_class' => 'list-nav', 'walker' => new wembley_walker_nav_menu) );                    ?>
				</nav>
				<?php } else { ?>
			<nav id="nav">
				<?php wp_nav_menu( array( 'theme_location' => 'primary', 'container' => 'nav', 'menu_class' => 'nav') ); ?>
				</nav>
				<?php } ?>
				<form role="search" method="get" class="search-form" action="<?php echo esc_url( home_url() ); ?>">
					<input type="search" placeholder="Search..." name="s">
					<input type="submit" value="Search">
				</form>
			</div>
			<span class="morphsearch-close"></span>
		 <?php $wb_menu_image  = get_theme_mod('menu_image'); 
         if(!empty($wb_menu_image)) { ?>
			<div class="wb-pg">
	       
   </div> 
	       <?php }
	   ?>
        </div>
	<?php } 
   /*--------------------------*
	/* Likes
	/*--------------------------*/
	function like_scripts() {
		wp_enqueue_script( 'jm_like_post', get_template_directory_uri().'/js/post-like.min.js', array('jquery'), '1.0', 1 );
		wp_localize_script( 'jm_like_post', 'ajax_var', array(
			'url' => admin_url( 'admin-ajax.php' ),
			'nonce' => wp_create_nonce( 'ajax-nonce' )
			)
		);
	}
	add_action( 'init', 'like_scripts' );

	/**
	 * (2) Save like data
	 */
	add_action( 'wp_ajax_nopriv_wb-post-like', 'jm_post_like' );
	add_action( 'wp_ajax_wb-post-like', 'jm_post_like' );
	function jm_post_like() {
		$nonce = $_POST['nonce'];
	    if ( ! wp_verify_nonce( $nonce, 'ajax-nonce' ) )
	        die ( 'Nope!' );
	
		if ( isset( $_POST['jm_post_like'] ) ) {
	
			$post_id = $_POST['post_id']; // post id
			$post_like_count = get_post_meta( $post_id, "_post_like_count", true ); // post like count
		
			if ( function_exists ( 'wp_cache_post_change' ) ) { // invalidate WP Super Cache if exists
				$GLOBALS["super_cache_enabled"]=1;
				wp_cache_post_change( $post_id );
			}
		
			if ( is_user_logged_in() ) { // user is logged in
				$user_id = get_current_user_id(); // current user
				$meta_POSTS = get_user_option( "_liked_posts", $user_id  ); // post ids from user meta
				$meta_USERS = get_post_meta( $post_id, "_user_liked" ); // user ids from post meta
				$liked_POSTS = NULL; // setup array variable
				$liked_USERS = NULL; // setup array variable
			
				if ( count( $meta_POSTS ) != 0 ) { // meta exists, set up values
					$liked_POSTS = $meta_POSTS;
				}
			
				if ( !is_array( $liked_POSTS ) ) // make array just in case
					$liked_POSTS = array();
				
				if ( count( $meta_USERS ) != 0 ) { // meta exists, set up values
					$liked_USERS = $meta_USERS[0];
				}		

				if ( !is_array( $liked_USERS ) ) // make array just in case
					$liked_USERS = array();
				
				$liked_POSTS['post-'.$post_id] = $post_id; // Add post id to user meta array
				$liked_USERS['user-'.$user_id] = $user_id; // add user id to post meta array
				$user_likes = count( $liked_POSTS ); // count user likes
	
				if ( !AlreadyLiked( $post_id ) ) { // like the post
					update_post_meta( $post_id, "_user_liked", $liked_USERS ); // Add user ID to post meta
					update_post_meta( $post_id, "_post_like_count", ++$post_like_count ); // +1 count post meta
					echo '<span>'.$post_like_count.'</span>'; // update count on front end

				} else { // unlike the post
					$pid_key = array_search( $post_id, $liked_POSTS ); // find the key
					$uid_key = array_search( $user_id, $liked_USERS ); // find the key
					unset( $liked_POSTS[$pid_key] ); // remove from array
					unset( $liked_USERS[$uid_key] ); // remove from array
					$user_likes = count( $liked_POSTS ); // recount user likes
					update_post_meta( $post_id, "_user_liked", $liked_USERS ); // Remove user ID from post meta
					update_post_meta($post_id, "_post_like_count", --$post_like_count ); // -1 count post meta
					echo '<span>'.$post_like_count.'</span>'; // update count on front end
				
				}
			
			} else { // user is not logged in (anonymous)
				$ip = $_SERVER['REMOTE_ADDR']; // user IP address
				$meta_IPS = get_post_meta( $post_id, "_user_IP" ); // stored IP addresses
				$liked_IPS = NULL; // set up array variable
			
				if ( count( $meta_IPS ) != 0 ) { // meta exists, set up values
					$liked_IPS = $meta_IPS[0];
				}
	
				if ( !is_array( $liked_IPS ) ) // make array just in case
					$liked_IPS = array();
				
				if ( !in_array( $ip, $liked_IPS ) ) // if IP not in array
					$liked_IPS['ip-'.$ip] = $ip; // add IP to array
			
				if ( !AlreadyLiked( $post_id ) ) { // like the post
					update_post_meta( $post_id, "_user_IP", $liked_IPS ); // Add user IP to post meta
					update_post_meta( $post_id, "_post_like_count", ++$post_like_count ); // +1 count post meta
					echo '<span>'.$post_like_count.'</span>'; // update count on front end
				
				} else { // unlike the post
					$ip_key = array_search( $ip, $liked_IPS ); // find the key
					unset( $liked_IPS[$ip_key] ); // remove from array
					update_post_meta( $post_id, "_user_IP", $liked_IPS ); // Remove user IP from post meta
					update_post_meta( $post_id, "_post_like_count", --$post_like_count ); // -1 count post meta
					echo '<span>'.$post_like_count.'</span>'; // update count on front end
				
				}
			}
		}
	
		exit;
	}

	/**
	 * (3) Test if user already liked post
	 */
	function AlreadyLiked( $post_id ) { // test if user liked before
		if ( is_user_logged_in() ) { // user is logged in
			$user_id = get_current_user_id(); // current user
			$meta_USERS = get_post_meta( $post_id, "_user_liked" ); // user ids from post meta
			$liked_USERS = ""; // set up array variable
		
			if ( count( $meta_USERS ) != 0 ) { // meta exists, set up values
				$liked_USERS = $meta_USERS[0];
			}
		
			if( !is_array( $liked_USERS ) ) // make array just in case
				$liked_USERS = array();
			
			if ( in_array( $user_id, $liked_USERS ) ) { // True if User ID in array
				return true;
			}
			return false;
		
		} else { // user is anonymous, use IP address for voting
	
			$meta_IPS = get_post_meta( $post_id, "_user_IP" ); // get previously voted IP address
			$ip = $_SERVER["REMOTE_ADDR"]; // Retrieve current user IP
			$liked_IPS = ""; // set up array variable
		
			if ( count( $meta_IPS ) != 0 ) { // meta exists, set up values
				$liked_IPS = $meta_IPS[0];
			}
		
			if ( !is_array( $liked_IPS ) ) // make array just in case
				$liked_IPS = array();
		
			if ( in_array( $ip, $liked_IPS ) ) { // True is IP in array
				return true;
			}
			return false;
		}
	
	}

	/**
	 *(4) Front end button
	 */
	function getPostLikeLink( $post_id ) {
		$like_count = get_post_meta( $post_id, "_post_like_count", true ); // get post likes
		$count = ( empty( $like_count ) || $like_count == "0" ) ? '' : esc_attr( $like_count );
		if ( AlreadyLiked( $post_id ) ) {
			$class = esc_attr( ' liked' );
			$title = esc_attr( 'Unlike' );
			$heart = '<i id="icon-like" class="fa fa-heart-o"></i>';
		} else {
			$class = esc_attr( '' );
			$title = esc_attr( '' );
			$heart = '<i id="icon-unlike" class="fa fa-heart-o"></i>';
		}
		$output = '<a href="#" class="wb-post-like'.$class.'" data-post_id="'.$post_id.'" title="'.$title.'">'.$heart.'&nbsp;<span>'.$count.'</span></a>';
		print $output;
	}	
	?>